@@ -259,19 +259,29 @@ class MultiModelTab:
     def update_test_size_label(self, *args):
         """Update test size label"""
         self.test_size_label.config(text=f"{self.test_size_var.get():.2f}")
-    
+        
     def load_data(self):
-        """Load data for training"""
-        if self.data_loaded_callback:
-            self.current_data = self.data_loaded_callback()
-            
-        if self.current_data is not None:
-            self.update_data_info()
-            self.populate_feature_lists()
-            self.train_button.config(state="normal")
-        else:
-            messagebox.showwarning("Advertencia", "No se pudieron cargar los datos")
-    
+        """Abrir cuadro de diálogo para cargar datos CSV"""
+        try:
+            filename = filedialog.askopenfilename(
+                title="Seleccionar archivo CSV",
+                filetypes=[("Archivos CSV", "*.csv"), ("Todos los archivos", "*.*")]
+            )
+            if not filename:
+                return  # Usuario canceló
+
+            self.current_data = pd.read_csv(filename)
+
+            if self.current_data is not None:
+                self.update_data_info()
+                self.populate_feature_lists()
+                self.train_button.config(state="normal")
+                messagebox.showinfo("Éxito", f"Datos cargados desde:\n{filename}")
+            else:
+                messagebox.showwarning("Advertencia", "No se pudieron cargar los datos")
+        except Exception as e:
+            messagebox.showerror("Error", f"No se pudo cargar el archivo:\n{str(e)}")
+        
     def update_data_info(self):
         """Update data information display"""
         if self.current_data is None:
